@@ -8,10 +8,10 @@ public:
     virtual int cols() const = 0;
 
     // y_out = A * x_in
-    virtual void perform_op(double* x_in, double* y_out) = 0;
+    virtual void perform_op(const double* x_in, double* y_out) = 0;
 
     // y_out = A' * x_in
-    virtual void perform_tprod(double* x_in, double* y_out) = 0;
+    virtual void perform_tprod(const double* x_in, double* y_out) = 0;
 
     virtual ~MatProd() {}
 };
