@@ -9,6 +9,7 @@ private:
     typedef Eigen::MatrixXd Matrix;
     typedef Eigen::VectorXd Vector;
     typedef Eigen::Map<Eigen::MatrixXd> MapMat;
+    typedef Eigen::Map<const Eigen::VectorXd> MapConstVec;
     typedef Eigen::Map<Eigen::VectorXd> MapVec;
     typedef Eigen::LDLT<Eigen::MatrixXd> LDLTSolver;
 
@@ -42,9 +43,9 @@ public:
     }
 
     // y_out = inv(A - sigma * I) * x_in
-    void perform_op(double* x_in, double* y_out)
+    void perform_op(const double* x_in, double* y_out)
     {
-        MapVec x(x_in, n);
+        MapConstVec x(x_in, n);
         MapVec y(y_out, n);
         y.noalias() = solver.solve(x);
     }
